==> ugene_1.3.3+repack.orig.tar.gz: ugene-1.3.3/src/ugene/src/logview/LogView.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_LOGVIEW_IMPL_
#define _GB2_LOGVIEW_IMPL_

#include "LogSettings.h"


#include <core_api/AppContext.h>

#include <QtCore/QHash>
#include <QtGui/QPlainTextEdit>

namespace GB2 {

class LogCache;
class LogMessage;

class LogViewDockWidget : public QWidget {
    Q_OBJECT
public:
    LogViewDockWidget(LogCache* c);

    void resetView();
    
    bool isShown(const LogMessage& msg);

    const LogSettings& getSettings() const {return settings;}

    void setSettings(const LogSettings& s); 

    const QString getLocalizedLevelName(LogLevel l) const {return localizedLevelNames[l];}


protected:
    void addMessage(const LogMessage& msg);
    void showEvent(QShowEvent *e);
    void hideEvent(QHideEvent *e);

private slots:

    void sl_onMessage(const LogMessage& msg);
	void popupMenu(const QPoint &pos);
    void sl_openSettingsDialog();
    void sl_logSettingsChanged();

private:
    
    QString prepareText(const LogMessage& msg) const;

    QPlainTextEdit*          edit;
	int                 messageCounter;
    LogCache*           cache;
    QAction*            showViewAction;
    QAction*            showSettingsAction;

    QString localizedLevelNames[LogLevel_NumLevels];
    LogSettings settings;

    bool connected; //for debug only
};

} //namespace

#endif

==> ugene_1.5.2+repack.orig.tar.gz: ugene-1.5.2/src/ugene/src/logview/LogView.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_LOGVIEW_IMPL_
#define _GB2_LOGVIEW_IMPL_

#include <core_services/LogSettings.h>

#include <QtCore/QHash>
#include <QtGui/QPlainTextEdit>

namespace GB2 {

class LogCache;
class LogMessage;

class LogViewDockWidget : public QWidget {
    Q_OBJECT
public:
    LogViewDockWidget(LogCache* c);

    void resetView();
    
    bool isShown(const LogMessage& msg);

    const LogSettings& getSettings() const {return settings;}

    void setSettings(const LogSettings& s); 

protected:
    void addMessage(const LogMessage& msg);
    void addText(const QString& text);
    void showEvent(QShowEvent *e);
    void hideEvent(QHideEvent *e);

private slots:

    void sl_onMessage(const LogMessage& msg);
	void popupMenu(const QPoint &pos);
    void sl_openSettingsDialog();
    void sl_logSettingsChanged();
    void sl_dumpCounters();
    void sl_clear();
    void sl_addSeparator();

private:
    
    QString prepareText(const LogMessage& msg) const;

    QPlainTextEdit*          edit;
	int                 messageCounter;
    LogCache*           cache;
    QAction*            showViewAction;
    QAction*            showSettingsAction;
    QAction*            dumpCountersAction;
    QAction*            clearAction;
    QAction*            addSeparatorAction;

    LogSettings settings;

    bool connected; //for debug only
};

} //namespace

#endif
